OGC API Support
===============

MapProxy supports OGC API Tiles and Maps both as :ref:`services <ogcapi_service_label>`, :ref:`tile sources <ogcapitiles_label>`, and :ref:`map sources <ogcapimaps_label>`
